BasePage class abstract

Inheritance
Available extensions

Constructors

BasePage({Key? key, bool isCovered = false, bool backEnable = true})
const

Properties

backEnable bool
是否 展示 返回 按钮
final
hashCode int
The hash code for this object.
no setterinherited
isCovered bool
内容是否铺满全屏
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aspectRatio({required double ratio}) Widget

Available on Widget, provided by the AWidget extension

设置宽高比
border(BoxBorder? border, {BorderRadiusGeometry? borderRadius}) Widget

Available on Widget, provided by the AWidget extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() BasePageState<BasePage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decoration(BoxDecoration? decoration) Widget

Available on Widget, provided by the AWidget extension

expand() Widget

Available on Widget, provided by the AWidget extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(VoidCallback? onTap, {HitTestBehavior behavior = HitTestBehavior.opaque}) Widget

Available on Widget, provided by the AWidget extension

点击
pading({double top = 0, double left = 0, double right = 0, double bottom = 0}) Widget

Available on Widget, provided by the AWidget extension

设置边距
padingSymmetric({double vertical = 0.0, double horizontal = 0.0}) Widget

Available on Widget, provided by the AWidget extension

设置边距
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visiable(bool visiable) Widget

Available on Widget, provided by the AWidget extension

是否可见

Operators

operator ==(Object other) bool
The equality operator.
inherited