BasePageState<T extends BasePage> class abstract

Inheritance

Constructors

BasePageState()

Properties

backgroundColor Color
getter/setter pair
backIcon Image
getter/setter pair
barBackgroundColor Color
getter/setter pair
barOpacity double
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
rightBarButton Widget
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleView Widget
getter/setter pair
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildAppBar() Widget
顶部导航栏
buildBodyHierarchy() Widget
containerBody() Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didTapBackBarAction() → void
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setAppBarBackgroundColor(Color newColor) → void
整个 背景的颜色
setAppBarOpacity(double opacity) → void
背景色 透明度
setBackgroundColor(Color newColor) → void
整个 背景的颜色
setBackIcon(Image newBackIcon) → void
返回 按钮
setRightBarButton(Widget button) → void
右侧的 按钮
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setTitle(String title) → void
标题
setTitleWidget(Widget newWidget) → void
自定义顶部 标题 视图
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited