AdMatch class

Constructors

AdMatch()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAndroidId() Future<String?>
安卓的 androidId
getIDFA() Future<String?>
获取苹果的IDFA 广告标识
getOAID() Future<String?>
安卓的OAID
match() → void
start() → void
track({required AdMatchingRequest request}) → void
上报