ClientActivityCase class

Annotations
  • @JsonSerializable.new()

Constructors

ClientActivityCase({required String tiktokCaseOneUrl, required String tiktokCaseTwoUrl, required String xhsCaseOneUrl, required String xhsCaseTwoUrl})
ClientActivityCase.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiktokCaseOneUrl String
getter/setter pair
tiktokCaseTwoUrl String
getter/setter pair
xhsCaseOneUrl String
getter/setter pair
xhsCaseTwoUrl String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited