ClientAdConfig class

Annotations
  • @JsonSerializable.new()

Constructors

ClientAdConfig({required String appId, required String bannerAdId, required bool enable, required String informationAdId, required String openScreenAdId, required String tablePlaqueAdId, required String topBannerAdId})
ClientAdConfig.fromJson(Map<String, dynamic> json)
factory

Properties

appId String
getter/setter pair
bannerAdId String
getter/setter pair
enable bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
informationAdId String
getter/setter pair
openScreenAdId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablePlaqueAdId String
getter/setter pair
topBannerAdId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited