Launch class

Annotations
  • @JsonSerializable.new(checked: true)

Constructors

Launch({required Config config, required String userId, required String hashId, required bool guest, required String token, required int realUserId})
Launch.fromJson(Map<String, dynamic> json)
factory

Properties

config Config
getter/setter pair
guest bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hashId String
getter/setter pair
realUserId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fetch() Future<void>