Application class

Constructors

Application()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

buildNumber String
获取构建号
no setter
packageName String
获取包名
no setter
version String
获取版本号
no setter

Static Methods

init() Future<void>
初始化,App启动时调用一次
openWebPage(String url) Future<void>
打开系统的网页