DeviceInfo class

Constructors

DeviceInfo({required String platform, required String channel, required String deviceID, required String brand, required String model})
const

Properties

brand String
设备品牌 苹果 固定 Apple,安卓 Redmi
final
channel String
渠道 苹果固定 ios
final
deviceID String
设备ID 苹果
final
hashCode int
The hash code for this object.
no setterinherited
model String
设备型号 苹果要转类似 (iPhone 11 Pro)
final
platform String
平台 苹果: ios 安卓: android
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited