Logger class

静态 Logger 工具类

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debug(Object? message, [Object? error, StackTrace? stackTrace]) → void
打印调试信息(最低等级) message 日志内容 error 可选的异常对象 stackTrace 可选的堆栈信息
error(Object? message, [Object? error, StackTrace? stackTrace]) → void
打印错误信息(严重等级) message 日志内容 error 可选的异常对象 stackTrace 可选的堆栈信息
info(Object? message, [Object? error, StackTrace? stackTrace]) → void
打印普通信息(信息等级) message 日志内容 error 可选的异常对象 stackTrace 可选的堆栈信息
init({String name = 'Roam'}) Future<void>
初始化 Logger(静态方法)
warning(Object? message, [Object? error, StackTrace? stackTrace]) → void
打印警告信息(警告等级) message 日志内容 error 可选的异常对象 stackTrace 可选的堆栈信息