Api class abstract

Annotations
  • @RestApi.new()

Constructors

Api(Dio dio, {String baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adMatch(AdMatchingRequest body) Future<ApiResult<EmptyResponse>>
广告匹配
launch(EmptyRequest body) Future<ApiResult<Launch>>
启动
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
userBehavior(Map<String, dynamic> body) Future<ApiResult>
后台数据埋点

Operators

operator ==(Object other) bool
The equality operator.
inherited