Environment enum

Inheritance
Available extensions

Values

dev → const Environment

开发

test → const Environment

测试

production → const Environment

正式

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
获取 host
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

change(Environment env) Future<void>
保存环境到本地
current() Future<Environment>
⚙️ 获取当前环境(优先缓存 → 原生推断 → 默认生产)
fromString(String value) Environment
从字符串映射枚举

Constants

values → const List<Environment>
A constant List of the values in this enum, in order of their declaration.