ApiResult<T> class

Annotations
  • @JsonSerializable.new(genericArgumentFactories: true)

Constructors

ApiResult({required int code, required String message, T? data, required String requestId})
ApiResult.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

code int
final
data → T?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
requestId String
final
responseCode ResponseCode
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object toJsonT(T value)) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited