AppStorage class

Available extensions

Constructors

AppStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

firstShowPayPage bool
getter/setter pair
hasSeenGuide bool
getter/setter pair
hasSeenPrivacy bool
getter/setter pair
isEn bool
当前是否为英语
no setter
isReview bool
当前是否为审核版本
getter/setter pair
language String
getter/setter pair
measureCount int
getter/setter pair
oaid String
getter/setter pair
receiveCouponTime int
getter/setter pair
terrainGuided bool
地形引导
getter/setter pair
token String
getter/setter pair