SpUtils class

Constructors

SpUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

preferences ↔ SharedPreferences
静态全局 SharedPreferences
latefinal

Static Methods

clear() Future<void>
清空所有
getValue<T>(String key) → T?
获取值,返回可选类型 T?
init() Future<void>
初始化(在 main() 启动时调用一次)
remove(String key) Future<void>
删除 key
setValue(String key, Object value) Future<void>