Device class
Constructors
- Device()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- androidChannel ↔ String?
-
getter/setter pair
- androidId ↔ String?
-
getter/setter pair
- appid → String
-
ID
no setter
- brand → String
-
设备品牌 苹果 固定 Apple,安卓 Redmi
no setter
- channel → String
-
渠道 苹果固定 ios
no setter
- deviceID → String
-
设备ID 苹果
no setter
- model → String
-
设备型号 原值
no setter
- platform → String
-
平台 苹果: ios 安卓: android
no setter
-
final
Static Methods
-
getDeviceInfo(
) → Future< DeviceInfo> -
init(
) → Future< void> - 初始化,App启动时调用一次