AppDialog class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
bottomSheet<T>(Widget widget, {BorderRadius borderRadius = const BorderRadius.vertical(top: Radius.circular(20)), bool isScrollControlled = false, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true})
→ Future<T?>
-
底部弹窗
-
center<T>(Widget widget, {EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 32), bool barrierDismissible = true})
→ Future<T?>
-
居中的弹窗
-
location<T>({required Widget body, Color barrierColor = Colors.transparent, bool barrierDismissible = true})
→ Future<T?>
-
弹窗自己设定位置
-
message<T>({required String title, required String content, String? cancelText, VoidCallback? pListener, String? confirmText, VoidCallback? nListener})
→ Future<T?>
-
-
permissionTips<T>({required String title, required String content})
→ Future<T?>
-
-
topDialog<T>(Widget widget, {EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 32), bool barrierDismissible = true})
→ Future<T?>
-
顶部的弹窗