ResponseCode enum
- Inheritance
- Available extensions
Values
- failure → const ResponseCode
-
其他错误
- codeExpired → const ResponseCode
-
验证码过期
- tokenExpired → const ResponseCode
-
token 失效
- success → const ResponseCode
-
成功
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ResponseCode> - A constant List of the values in this enum, in order of their declaration.